@@ -1,7 +1,8 @@
 #' Mock study data for examples
-#' 
-#' Mock clinical study data for examples to test data manipulation and statistical functions
-#' 
+#'
+#' Mock clinical study data for examples to test data manipulation and statistical functions.
+#'   The function \code{muck_up_mockstudy()} is used in examples for \code{\link{compare.data.frame}}.
+#'
 #' @format A data frame with 1499 observations on the following 15 variables:
 #'   \describe{
 #'     \item{\code{case}}{a numeric identifier-patient ID}
@@ -24,4 +25,32 @@
 #' @examples
 #' data(mockstudy)
 #' str(mockstudy)
+#' @name mockstudy
+NULL
+#> NULL
+
+#' @rdname mockstudy
 "mockstudy"
+
+#' @rdname mockstudy
+#' @export
+muck_up_mockstudy <- function()
+{
+  mockstudy <- arsenal::mockstudy
+  mockstudy2 <- mockstudy[c(1, 3, 6, 10:nrow(mockstudy), 2, 4), ]
+  mockstudy2$sex <- factor(mockstudy2$sex, levels = c("Female", "Male"))
+  mockstudy2$ps[3] <- NA
+  mockstudy2$ast[1:3] <- 36
+  mockstudy2$age <- NULL
+  mockstudy2$fu_time <- mockstudy2$fu.time
+  mockstudy2$fu.time <- NULL
+  mockstudy2$`fu stat` <- mockstudy2$fu.stat
+  mockstudy2$fu.stat <- NULL
+  mockstudy2$Arm <- mockstudy2$arm
+  mockstudy2$arm <- NULL
+  mockstudy2$hgb[is.na(mockstudy2$hgb)] <- -9
+  mockstudy2$race[mockstudy2$race == "Caucasian"] <- "caucasian"
+  mockstudy2$race <- factor(mockstudy2$race)
+  attr(mockstudy2$sex, "label") <- "Sex (M/F)"
+  mockstudy2
+}
