@@ -59,44 +59,55 @@ write2 <- function(object, file, ..., output_format)
   UseMethod("write2")
 }
 
+write2_using_summary <- function(object, file, ..., output_format = NULL)
+{
+  write2.default(object = object, file = file, FUN = summary, ..., output_format = output_format)
+}
+
+write2_using_print <- function(object, file, ..., output_format = NULL)
+{
+  write2.default(object = object, file = file, FUN = print, ..., output_format = output_format)
+}
+
 ############################ write2 for arsenal objects ############################
 
 #' @rdname write2
 #' @export
-write2.tableby <- function(object, file, ..., output_format = NULL)
-{
-  write2.default(object = object, file = file, FUN = summary, ..., output_format = output_format)
-}
+write2.tableby <- write2_using_summary
 
 #' @rdname write2
 #' @export
-write2.modelsum <- function(object, file, ..., output_format = NULL)
-{
-  write2.default(object = object, file = file, FUN = summary, ..., output_format = output_format)
-}
+write2.modelsum <- write2_using_summary
 
 #' @rdname write2
 #' @export
-write2.freqlist <- function(object, file, ..., output_format = NULL)
-{
-  write2.default(object = object, file = file, FUN = summary, ..., output_format = output_format)
-}
+write2.freqlist <- write2_using_summary
+
+#' @rdname write2
+#' @export
+write2.compare.data.frame <- write2_using_summary
+
+#' @rdname write2
+#' @export
+write2.summary.compare.data.frame <- write2_using_print
+
+#' @rdname write2
+#' @export
+write2.verbatim <- write2_using_print
+
+#' @rdname write2
+#' @export
+write2.yaml <- write2_using_print
 
 ############################ write2 for external objects ############################
 
 #' @rdname write2
 #' @export
-write2.knitr_kable <- function(object, file, ..., output_format = NULL)
-{
-  write2.default(object = object, file = file, FUN = print, ..., output_format = output_format)
-}
+write2.knitr_kable <- write2_using_print
 
 #' @rdname write2
 #' @export
-write2.xtable <- function(object, file, ..., output_format = NULL)
-{
-  write2.default(object = object, file = file, FUN = print, ..., output_format = output_format)
-}
+write2.xtable <- write2_using_print
 
 #' @rdname write2
 #' @export
@@ -118,8 +129,17 @@ write2.list <- function(object, file, ..., append. = FALSE, render. = TRUE, keep
   filename <- paste0(file, ".md")
   if(!append. || !file.exists(filename)) file.create(filename)
 
-  # separate the tables with a few blank lines
-  object2 <- c(object, as.list(rep("\n\n", times = length(object))))[order(c(seq_along(object), seq_along(object) + 0.5))]
+  # find any YAML specifications
+  idx <- vapply(object, is.yaml, NA)
+  if(sum(idx) > 0)
+  {
+    yamls <- Reduce(c, object[idx])
+    object <- object[!idx]
+    write2(yamls, file = file, ..., keep.md = TRUE, append = TRUE, render. = FALSE, output_format = output_format)
+  }
+
+  # separate the tables with a few blank lines, leading with the blank lines
+  object2 <- c(object, as.list(rep("\n\n", times = length(object))))[order(c(seq_along(object), seq_along(object) - 0.5))]
 
   lapply(object2, write2, file = file, ..., keep.md = TRUE, append. = TRUE, render. = FALSE, output_format = output_format)
 
@@ -128,30 +148,3 @@ write2.list <- function(object, file, ..., append. = FALSE, render. = TRUE, keep
   invisible(object)
 }
 
-############################ write2 for raw output ############################
-
-#' @rdname write2
-#' @export
-write2.verbatim <- function(object, file, ..., output_format = NULL)
-{
-  write2.default(object = object, file = file, FUN = print, ..., output_format = output_format)
-}
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
